@@ -34,20 +34,15 @@
 #include <X11/Xlib.h>
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
+#include <unistd.h>
+#include <libslab/slab.h>
 
-#include "tile.h"
-#include "application-tile.h"
-#include "document-tile.h"
-#include "directory-tile.h"
-#include "system-tile.h"
 #include "hard-drive-status-tile.h"
 #include "network-status-tile.h"
 
 #include "tile-table.h"
 
 #include "tomboykeybinder.h"
-#include "libslab-utils.h"
-#include "double-click-detector.h"
 
 #define ROOT_GCONF_DIR             "/desktop/gnome/applications/main-menu"
 #define CURRENT_PAGE_GCONF_KEY     ROOT_GCONF_DIR "/file-area/file_class"
@@ -264,32 +259,18 @@ enum {
 
 static Atom slab_action_main_menu_atom = None;
 
-MainMenuUI *
-main_menu_ui_new (PanelApplet *applet)
+static gboolean
+main_menu_delayed_setup (MainMenuUI *this)
 {
-	MainMenuUI        *this;
-	MainMenuUIPrivate *priv;
+	MainMenuUIPrivate *priv = PRIVATE (this);
 
-	gchar *glade_xml_path;
-
-
-	this = g_object_new (MAIN_MENU_UI_TYPE, NULL);
-	priv = PRIVATE (this);
-
-	priv->panel_applet = applet;
-
-	glade_xml_path = g_build_filename (DATADIR, PACKAGE, "slab-window.glade", NULL);
-
-	priv->main_menu_xml    = glade_xml_new (glade_xml_path, "slab-main-menu-window", NULL);
-	priv->panel_button_xml = glade_xml_new (glade_xml_path, "slab-panel-button-root", NULL);
-	g_free (glade_xml_path);
+	if (priv->recently_used_store_monitor != NULL)
+		return; /* already setup */
 
 	libslab_checkpoint ("main_menu_ui_new(): setup_recently_used_store_monitor");
 	setup_recently_used_store_monitor (this, TRUE);
 	libslab_checkpoint ("main_menu_ui_new(): setup_bookmark_agents");
 	setup_bookmark_agents    (this);
-	libslab_checkpoint ("main_menu_ui_new(): create_panel_button");
-	create_panel_button      (this);
 	libslab_checkpoint ("main_menu_ui_new(): create_slab_window");
 	create_slab_window       (this);
 	libslab_checkpoint ("main_menu_ui_new(): create_search_section");
@@ -324,6 +305,33 @@ main_menu_ui_new (PanelApplet *applet)
 	libslab_checkpoint ("main_menu_ui_new(): apply_lockdown_settings");
 	apply_lockdown_settings (this);
 
+	return FALSE;
+}
+
+MainMenuUI *
+main_menu_ui_new (PanelApplet *applet)
+{
+	MainMenuUI        *this;
+	MainMenuUIPrivate *priv;
+
+	gchar *glade_xml_path;
+
+
+	this = g_object_new (MAIN_MENU_UI_TYPE, NULL);
+	priv = PRIVATE (this);
+
+	priv->panel_applet = applet;
+
+	glade_xml_path = g_build_filename (DATADIR, PACKAGE, "slab-window.glade", NULL);
+
+	priv->main_menu_xml    = glade_xml_new (glade_xml_path, "slab-main-menu-window", NULL);
+	priv->panel_button_xml = glade_xml_new (glade_xml_path, "slab-panel-button-root", NULL);
+	g_free (glade_xml_path);
+
+	libslab_checkpoint ("main_menu_ui_new(): create_panel_button");
+	create_panel_button (this);
+	g_timeout_add_seconds (5, (GSourceFunc) main_menu_delayed_setup, this);
+
 	return this;
 }
 
@@ -441,7 +449,7 @@ main_menu_ui_finalize (GObject *g_obj)
 		g_object_unref (G_OBJECT (g_object_get_data (
 			G_OBJECT (priv->panel_buttons [i]), "double-click-detector")));
 
-		gtk_widget_unref (GTK_WIDGET (priv->panel_buttons [i]));
+		g_object_unref (priv->panel_buttons [i]);
 	}
 
 	libslab_gconf_notify_remove (priv->search_cmd_gconf_mntr_id);
@@ -505,7 +513,7 @@ create_panel_button (MainMenuUI *this)
 
 		button_parent = gtk_widget_get_parent (GTK_WIDGET (priv->panel_buttons [i]));
 
-		gtk_widget_ref (GTK_WIDGET (priv->panel_buttons [i]));
+		g_object_ref (priv->panel_buttons [i]);
 		gtk_container_remove (
 			GTK_CONTAINER (button_parent), GTK_WIDGET (priv->panel_buttons [i]));
 
@@ -1001,6 +1009,7 @@ setup_recently_used_store_monitor (MainMenuUI *this, gboolean is_startup)
 
 	path = get_recently_used_store_filename ();
 	file = g_file_new_for_path (path);
+	g_free (path);
 
 	monitor = g_file_monitor_file (file, 0, NULL, NULL);
 	if (monitor) {
@@ -1011,6 +1020,8 @@ setup_recently_used_store_monitor (MainMenuUI *this, gboolean is_startup)
 				  this);
 	}
 
+	g_object_unref (file);
+
 	priv->recently_used_store_monitor = monitor;
 
 	if (priv->recently_used_timeout_id != 0)
@@ -1066,7 +1077,7 @@ item_to_user_doc_tile (BookmarkItem *item, gpointer data)
 			return TILE (document_tile_new_force_icon (item->uri, item->mime_type,
 				item->mtime, "gnome-mime-application-vnd.oasis.opendocument.text-template"));
 	}
-	return TILE (document_tile_new (item->uri, item->mime_type, item->mtime));
+	return TILE (document_tile_new (BOOKMARK_STORE_USER_DOCS, item->uri, item->mime_type, item->mtime));
 }
 
 static Tile *
@@ -1083,12 +1094,14 @@ item_to_recent_doc_tile (BookmarkItem *item, gpointer data)
 
 	GList *node;
 
+	/* we no longer do our own thumbnailing so this "should" not hang on stale mounts, slow endpoints ... */
+	/*
 	if (! g_str_has_prefix (item->uri, "file://"))
 		return NULL;
 
 	for (node = priv->mounts; ! is_nfs && node; node = node->next) {
 		mount = node->data;
-		volume = g_mount_get_volume (mount);
+		volume = g_mount_get_volume (mount); //need to check for null here
 
 		nfs_id = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_NFS_MOUNT);
 		is_nfs = (nfs_id != NULL);
@@ -1106,11 +1119,12 @@ item_to_recent_doc_tile (BookmarkItem *item, gpointer data)
 
 	if (! is_local)
 		return NULL;
+	*/
 
 	if (bookmark_agent_has_item (priv->bm_agents [BOOKMARK_STORE_USER_DOCS], item->uri))
 		return NULL;
 
-	return TILE (document_tile_new (item->uri, item->mime_type, item->mtime));
+	return TILE (document_tile_new (BOOKMARK_STORE_RECENT_DOCS, item->uri, item->mime_type, item->mtime));
 }
 
 static Tile *
@@ -1124,13 +1138,17 @@ item_to_system_tile (BookmarkItem *item, gpointer data)
 {
 	Tile  *tile;
 	gchar *basename;
-
+	gchar *translated_title;
 
 	if (app_is_in_blacklist (item->uri))
 		return NULL;
+	
+	translated_title = item->title ? _(item->title) : NULL;
 
-	tile = TILE (system_tile_new (item->uri, item->title));
+	tile = TILE (system_tile_new (item->uri, translated_title));
 
+	/* with 0.9.12 we start with clean system area - see move_system_area_to_new_set
+	   no longer need this code to clean up old junk
 	if (tile)
 		return tile;
 
@@ -1141,9 +1159,10 @@ item_to_system_tile (BookmarkItem *item, gpointer data)
 		basename = item->uri;
 
 	if (! libslab_strcmp (basename, "control-center.desktop"))
-		tile = TILE (system_tile_new ("gnomecc.desktop", item->title));
+		tile = TILE (system_tile_new ("gnomecc.desktop", translated_title));
 	else if (! libslab_strcmp (basename, "zen-installer.desktop"))
-		tile = TILE (system_tile_new ("package-manager.desktop", item->title));
+		tile = TILE (system_tile_new ("package-manager.desktop", translated_title));
+	*/
 
 	return tile;
 }
@@ -1848,6 +1867,7 @@ panel_button_clicked_cb (GtkButton *button, gpointer user_data)
 
 	gboolean visible;
 
+	main_menu_delayed_setup (this);
 
 	detector = DOUBLE_CLICK_DETECTOR (
 		g_object_get_data (G_OBJECT (toggle), "double-click-detector"));
@@ -1860,7 +1880,7 @@ panel_button_clicked_cb (GtkButton *button, gpointer user_data)
 		else
 			gtk_widget_hide (priv->slab_window);
 
-		visible = GTK_WIDGET_VISIBLE (priv->slab_window);
+  		visible = GTK_WIDGET_VISIBLE (priv->slab_window);
 	}
 
 	gtk_toggle_button_set_active (priv->panel_button, visible);
@@ -2149,11 +2169,11 @@ slab_window_allocate_cb (GtkWidget *widget, GtkAllocation *alloc, gpointer user_
 
 	if (orient == PANEL_APPLET_ORIENT_UP || orient == PANEL_APPLET_ORIENT_DOWN) {
 		if ((slab_geom.x + slab_geom.width) > (monitor_geom.x + monitor_geom.width))
-			slab_geom.x = button_geom.x + button_geom.width - slab_geom.width;
+			slab_geom.x = MAX (monitor_geom.x, monitor_geom.x + monitor_geom.width - slab_geom.width);
 	}
 	else {
 		if ((slab_geom.y + slab_geom.height) > (monitor_geom.y + monitor_geom.height))
-			slab_geom.y = button_geom.y + button_geom.height - slab_geom.height;
+			slab_geom.y = MAX (monitor_geom.y, monitor_geom.y + monitor_geom.height - slab_geom.height);
 	}
 
 	gtk_window_move (GTK_WINDOW (priv->slab_window), slab_geom.x, slab_geom.y);
@@ -2305,10 +2325,14 @@ more_buttons_clicked_cb (GtkButton *button, gpointer user_data)
 		if (GTK_WIDGET (button) == priv->more_buttons [APPS_PAGE])
 			ditem_id = libslab_get_gconf_value (APP_BROWSER_GCONF_KEY);
 		else if (GTK_WIDGET (button) == priv->more_buttons [DOCS_PAGE]) {
-			dir = g_build_filename (g_get_home_dir (), "Documents", NULL);
+			dir = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
+			if (! dir)
+			      dir = g_build_filename (g_get_home_dir (), "Documents", NULL);
 
-			if (! g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
+			if (! g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
+				g_free (dir);
 				dir = g_strdup (g_get_home_dir ());
+			}
 
 			uri = g_filename_to_uri (dir, NULL, NULL);
 
@@ -2372,6 +2396,7 @@ panel_menu_about_cb (BonoboUIComponent *component, gpointer user_data, const gch
 	MainMenuUI *this        = MAIN_MENU_UI (user_data);
 	MainMenuUIPrivate *priv = PRIVATE      (this);
 
+	main_menu_delayed_setup (this);
 
 	if (! priv->panel_about_dialog) {
 		priv->panel_about_dialog = gtk_about_dialog_new ();
@@ -2417,7 +2442,7 @@ panel_applet_change_background_cb (PanelApplet *applet, PanelAppletBackgroundTyp
 	gtk_widget_set_style (GTK_WIDGET (priv->panel_applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (priv->panel_applet), rc_style);
-	gtk_rc_style_unref (rc_style);
+	g_object_unref (rc_style);
 
 	switch (type) {
 		case PANEL_NO_BACKGROUND:
